rapido.souper
=============

.. image:: https://secure.travis-ci.org/collective/rapido.souper.png?branch=master
    :target: http://travis-ci.org/collective/rapido.souper
    :alt: Tests
.. image:: https://landscape.io/github/collective/rapido.souper/master/landscape.svg?style=flat
    :target: https://landscape.io/github/collective/rapido.souper/master
    :alt: Code Health
.. image:: https://coveralls.io/repos/collective/rapido.souper/badge.svg?branch=master&service=github
    :target: https://coveralls.io/github/collective/rapido.souper?branch=master
    :alt: Coverage

rapido.souper provides a `Souper-based <https://pypi.python.org/pypi/souper>`_
persistence layer for Rapido applications.
